@@ -16,4 +16,10 @@ from .peak_processing import *
 from . import event_processing
 from .event_processing import *
 
+from . import double_scatter
+from .double_scatter import *
+
+from . import led_calibration
+from .led_calibration import *
+
 from . import x1t_cuts
